import z from 'zod';
import { queryOffsetLimitParser } from '../../common/parsers/queryParams';
import { channelIdParser, channelIdParserClassic } from '../../channel/parsers';
import { edgeUnitParser } from '../../graph/parsers';
import { currencyAmountParser } from '../../currencies/parsers';
import { BeneficiaryId } from '../types';

const listBeneficiariesSrcDstParser = z
  .object({
    src: channelIdParserClassic.optional(),
    dst: channelIdParserClassic.optional(),
  })
  .superRefine(({ src, dst }, ctx) => {
    if (!src && !dst) {
      ctx.addIssue({
        code: z.ZodIssueCode.custom,
        message: 'src or dst must be provided',
        path: [ctx.path[0], ctx.path[1]],
      });
    }
    if (src === dst) {
      ctx.addIssue({
        code: z.ZodIssueCode.custom,
        message: 'src and dst cannot be the same',
        path: [ctx.path[0], ctx.path[1]],
      });
    }
  });

export const listBeneficiariesQueryParser = queryOffsetLimitParser.and(listBeneficiariesSrcDstParser);

export const beneficiaryIdParser = z.string().transform((id) => id as BeneficiaryId);

// dst, src, uuid (TODO change to id on frontend), unit, amt, createdAt
export const listBeneficiariesResponseItemParser = z.object({
  dst: channelIdParser,
  src: channelIdParser,
  id: beneficiaryIdParser,
  unit: edgeUnitParser,
  amt: currencyAmountParser, // given unit is % too, probably not only "currency" amount
});

export const listBeneficiariesResponseParser = z.object({
  total: z.number(),
  items: z.array(listBeneficiariesResponseItemParser),
});
