import z from 'zod';
import type { ApiSubscription } from './types';
import type { ListResponseTrait } from '../response/types';
import type { ApiSubscriptionWithProceedContext } from './types';
export declare const subscriptionListQueryParser: z.ZodObject<{
    limit: z.ZodOptional<z.ZodEffects<z.ZodUnion<[z.ZodNumber, z.ZodEffects<z.ZodString, number, string>]>, number, string | number>>;
    offset: z.ZodDefault<z.ZodEffects<z.ZodUnion<[z.ZodNumber, z.ZodEffects<z.ZodString, number, string>]>, number, string | number>>;
    src: z.ZodOptional<z.ZodEffects<z.ZodString, {
        type: "user";
        id: import("../user/types").UserIdBrand;
    }, string>>;
    dst: z.ZodOptional<z.ZodEffects<z.ZodString, {
        type: "channel";
        id: import("../blog/id.types").BlogIdBrand | "COMMON 06" | import("../collective/types").CollectiveIdBrand | import("../mixspace/id.types").MixspaceIdBrand;
    }, string>>;
}, "strip", z.ZodTypeAny, {
    offset: number;
    limit?: number | undefined;
    src?: {
        type: "user";
        id: import("../user/types").UserIdBrand;
    } | undefined;
    dst?: {
        type: "channel";
        id: import("../blog/id.types").BlogIdBrand | "COMMON 06" | import("../collective/types").CollectiveIdBrand | import("../mixspace/id.types").MixspaceIdBrand;
    } | undefined;
}, {
    limit?: string | number | undefined;
    offset?: string | number | undefined;
    src?: string | undefined;
    dst?: string | undefined;
}>;
export declare const subscriptionListResponseParser: z.ZodEffects<z.ZodAny, ListResponseTrait<ApiSubscription>, any>;
export declare const subscriptionGetOneParamsParser: z.ZodObject<{
    id: z.ZodEffects<z.ZodString, import("../stripe/types").StripeSubscriptionIdBrand, string>;
}, "strip", z.ZodTypeAny, {
    id: import("../stripe/types").StripeSubscriptionIdBrand;
}, {
    id: string;
}>;
export declare const subscriptionRecurringParser: z.ZodBoolean;
export declare const subscriptionStatusParser: z.ZodEnum<["ACTIVE", "INACTIVE", "INCOMPLETE", "INCOMPLETE_EXPIRED", "TRIALING", "PAST_DUE", "CANCELED", "UNPAID"]>;
export declare const subscriptionApiRecurringParser: z.ZodObject<{
    recurring: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    recurring: boolean;
}, {
    recurring: boolean;
}>;
export declare const subscriptionRecurringAndStatusParser: z.ZodObject<{
    status: z.ZodEnum<["ACTIVE", "INACTIVE", "INCOMPLETE", "INCOMPLETE_EXPIRED", "TRIALING", "PAST_DUE", "CANCELED", "UNPAID"]>;
    recurring: z.ZodBoolean;
}, "strip", z.ZodTypeAny, {
    status: "ACTIVE" | "INCOMPLETE" | "INACTIVE" | "INCOMPLETE_EXPIRED" | "TRIALING" | "PAST_DUE" | "CANCELED" | "UNPAID";
    recurring: boolean;
}, {
    status: "ACTIVE" | "INCOMPLETE" | "INACTIVE" | "INCOMPLETE_EXPIRED" | "TRIALING" | "PAST_DUE" | "CANCELED" | "UNPAID";
    recurring: boolean;
}>;
export declare const subscriptionOriginTypeParser: z.ZodEnum<["stripe", "paypal"]>;
export declare const subscriptionCreateInputParser: z.ZodObject<{
    amt: z.ZodEffects<z.ZodUnion<[z.ZodNumber, z.ZodEffects<z.ZodString, number, string>]>, number, string | number>;
    unit: z.ZodEnum<["AED", "AFN", "ALL", "AMD", "ANG", "AOA", "ARS", "AUD", "AWG", "AZN", "BAM", "BBD", "BDT", "BGN", "BHD", "BMD", "BND", "BOB", "BOV", "BRL", "BSD", "BTN", "BWP", "BYN", "BZD", "CAD", "CDF", "CHE", "CHF", "CHW", "CLF", "CNY", "COP", "COU", "CRC", "CUC", "CUP", "CVE", "CZK", "DKK", "DOP", "DZD", "EGP", "ERN", "ETB", "EUR", "FJD", "FKP", "GBP", "GEL", "GHS", "GIP", "GMD", "GTQ", "GYD", "HKD", "HNL", "HRK", "HTG", "IDR", "ILS", "INR", "IQD", "IRR", "ISK", "JMD", "JOD", "KES", "KGS", "KHR", "KPW", "KWD", "KYD", "KZT", "LAK", "LBP", "LKR", "LRD", "LSL", "LYD", "MAD", "MDL", "MKD", "MMK", "MNT", "MOP", "MRU", "MUR", "MVR", "MWK", "MXN", "MXV", "MYR", "MZN", "NAD", "NGN", "NIO", "NOK", "NPR", "NZD", "OMR", "PAB", "PEN", "PGK", "PHP", "PKR", "PLN", "QAR", "RON", "RSD", "RUB", "SAR", "SBD", "SCR", "SDG", "SEK", "SGD", "SHP", "SLL", "SOS", "SRD", "SSP", "STN", "SVC", "SYP", "SZL", "THB", "TJS", "TMT", "TND", "TOP", "TRY", "TTD", "TZS", "UAH", "USD", "USN", "UYI", "UYU", "UYW", "UZS", "VES", "WST", "XAG", "XAU", "XBA", "XBB", "XBC", "XBD", "XCD", "XDR", "XPD", "XPT", "XSU", "XTS", "XUA", "XXX", "YER", "ZAR", "ZMW", "ZWL", "BIF", "PYG", "CLP", "RWF", "DJF", "UGX", "GNF", "VND", "JPY", "VUV", "KMF", "XAF", "KRW", "XOF", "MGA", "XPF", ...("UGX" | "HUF" | "TWD")[]]>;
    src: z.ZodEffects<z.ZodString, {
        type: "user";
        id: import("../user/types").UserIdBrand;
    }, string>;
    dst: z.ZodEffects<z.ZodString, {
        type: "channel";
        id: import("../blog/id.types").BlogIdBrand | "COMMON 06" | import("../collective/types").CollectiveIdBrand | import("../mixspace/id.types").MixspaceIdBrand;
    }, string>;
    recurring: z.ZodBoolean;
    idempotencyKey: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    amt: number;
    unit: "USD" | "EUR" | "BIF" | "PYG" | "CLP" | "RWF" | "DJF" | "UGX" | "GNF" | "VND" | "JPY" | "VUV" | "KMF" | "XAF" | "KRW" | "XOF" | "MGA" | "XPF" | "HUF" | "TWD" | "AED" | "AFN" | "ALL" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "KES" | "KGS" | "KHR" | "KPW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MYR" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "QAR" | "RON" | "RSD" | "RUB" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TZS" | "UAH" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "WST" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XPD" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
    src: {
        type: "user";
        id: import("../user/types").UserIdBrand;
    };
    dst: {
        type: "channel";
        id: import("../blog/id.types").BlogIdBrand | "COMMON 06" | import("../collective/types").CollectiveIdBrand | import("../mixspace/id.types").MixspaceIdBrand;
    };
    recurring: boolean;
    idempotencyKey?: string | undefined;
}, {
    amt: string | number;
    unit: "USD" | "EUR" | "BIF" | "PYG" | "CLP" | "RWF" | "DJF" | "UGX" | "GNF" | "VND" | "JPY" | "VUV" | "KMF" | "XAF" | "KRW" | "XOF" | "MGA" | "XPF" | "HUF" | "TWD" | "AED" | "AFN" | "ALL" | "AMD" | "ANG" | "AOA" | "ARS" | "AUD" | "AWG" | "AZN" | "BAM" | "BBD" | "BDT" | "BGN" | "BHD" | "BMD" | "BND" | "BOB" | "BOV" | "BRL" | "BSD" | "BTN" | "BWP" | "BYN" | "BZD" | "CAD" | "CDF" | "CHE" | "CHF" | "CHW" | "CLF" | "CNY" | "COP" | "COU" | "CRC" | "CUC" | "CUP" | "CVE" | "CZK" | "DKK" | "DOP" | "DZD" | "EGP" | "ERN" | "ETB" | "FJD" | "FKP" | "GBP" | "GEL" | "GHS" | "GIP" | "GMD" | "GTQ" | "GYD" | "HKD" | "HNL" | "HRK" | "HTG" | "IDR" | "ILS" | "INR" | "IQD" | "IRR" | "ISK" | "JMD" | "JOD" | "KES" | "KGS" | "KHR" | "KPW" | "KWD" | "KYD" | "KZT" | "LAK" | "LBP" | "LKR" | "LRD" | "LSL" | "LYD" | "MAD" | "MDL" | "MKD" | "MMK" | "MNT" | "MOP" | "MRU" | "MUR" | "MVR" | "MWK" | "MXN" | "MXV" | "MYR" | "MZN" | "NAD" | "NGN" | "NIO" | "NOK" | "NPR" | "NZD" | "OMR" | "PAB" | "PEN" | "PGK" | "PHP" | "PKR" | "PLN" | "QAR" | "RON" | "RSD" | "RUB" | "SAR" | "SBD" | "SCR" | "SDG" | "SEK" | "SGD" | "SHP" | "SLL" | "SOS" | "SRD" | "SSP" | "STN" | "SVC" | "SYP" | "SZL" | "THB" | "TJS" | "TMT" | "TND" | "TOP" | "TRY" | "TTD" | "TZS" | "UAH" | "USN" | "UYI" | "UYU" | "UYW" | "UZS" | "VES" | "WST" | "XAG" | "XAU" | "XBA" | "XBB" | "XBC" | "XBD" | "XCD" | "XDR" | "XPD" | "XPT" | "XSU" | "XTS" | "XUA" | "XXX" | "YER" | "ZAR" | "ZMW" | "ZWL";
    src: string;
    dst: string;
    recurring: boolean;
    idempotencyKey?: string | undefined;
}>;
export declare const subscriptionCreateResponseParser: z.ZodEffects<z.ZodAny, ApiSubscriptionWithProceedContext, any>;
export declare const subscriptionUpdateInputParser: z.ZodObject<{
    amt: z.ZodOptional<z.ZodEffects<z.ZodUnion<[z.ZodNumber, z.ZodEffects<z.ZodString, number, string>]>, number, string | number>>;
    idempotencyKey: z.ZodOptional<z.ZodString>;
}, "strip", z.ZodTypeAny, {
    amt?: number | undefined;
    idempotencyKey?: string | undefined;
}, {
    amt?: string | number | undefined;
    idempotencyKey?: string | undefined;
}>;
export declare const subscriptionUpdateParamsParser: z.ZodObject<{
    id: z.ZodEffects<z.ZodString, import("../stripe/types").StripeSubscriptionIdBrand, string>;
}, "strip", z.ZodTypeAny, {
    id: import("../stripe/types").StripeSubscriptionIdBrand;
}, {
    id: string;
}>;
export declare const subscriptionUpdateResponseParser: z.ZodEffects<z.ZodAny, ApiSubscriptionWithProceedContext, any>;
export declare const subscriptionDeleteParamsParser: z.ZodObject<{
    id: z.ZodEffects<z.ZodString, import("../stripe/types").StripeSubscriptionIdBrand, string>;
}, "strip", z.ZodTypeAny, {
    id: import("../stripe/types").StripeSubscriptionIdBrand;
}, {
    id: string;
}>;
